@@ -142,6 +142,12 @@ ODOO_MSGS = {
         CHECK_DESCRIPTION,
     ),
     "C8112": ("Missing ./README.rst file. Template here: %s", "missing-readme", CHECK_DESCRIPTION),
+    "C8113": (
+        "No wizard class for model directory. See the complete structure "
+        "https://github.com/OCA/odoo-community.org/blob/master/website/Contribution/CONTRIBUTING.rst#complete-structure",
+        "no-wizard-in-models",
+        CHECK_DESCRIPTION,
+    ),
     "E8101": (
         "The author key in the manifest file must be a string (with comma separated values)",
         "manifest-author-string",
@@ -234,6 +240,12 @@ ODOO_MSGS = {
         "odoo-addons-relative-import",
         CHECK_DESCRIPTION,
     ),
+    "W8155": (
+        "Used builtin function `itertools.groupby`. Prefer `odoo.tools.groupby` instead. "
+        "More info about https://github.com/odoo/odoo/issues/105376",
+        "bad-builtin-groupby",
+        CHECK_DESCRIPTION,
+    ),
 }
 
 DFTL_MANIFEST_REQUIRED_KEYS = ["license"]
@@ -519,6 +531,8 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
             if len(inh_nodes) <= 1:
                 continue
             path_nodes = []
+            # deterministic order of the output
+            inh_nodes = sorted(inh_nodes, key=lambda node: (node.root().file, node.lineno))
             first_node = inh_nodes.pop()
             for node in inh_nodes:
                 relpath = os.path.relpath(node.root().file, os.getcwd())
@@ -704,6 +718,7 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
 
     @utils.only_required_for_messages(
         "attribute-string-redundant",
+        "bad-builtin-groupby",
         "context-overridden",
         "external-request-timeout",
         "invalid-commit",
@@ -776,7 +791,11 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
                             "renamed-field-parameter", node=node, args=(argument.arg, deprecated[argument.arg])
                         )
                     # no write in compute method
-                    if argument.arg == "compute" and isinstance(argument.value, (nodes.Const, nodes.Name)):
+                    if (
+                        self.linter.is_message_enabled("no-write-in-compute", argument.lineno)
+                        and argument.arg == "compute"
+                        and isinstance(argument.value, (nodes.Const, nodes.Name))
+                    ):
                         method_name = (
                             argument.value.value
                             if isinstance(argument.value, nodes.Const)
@@ -784,7 +803,7 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
                             if isinstance(argument.value, nodes.Name)
                             else None
                         )
-                        if method_name and self.is_class_odoo_models:
+                        if method_name and self.class_odoo_models:
                             self.odoo_computes.add(method_name)
                 if (
                     isinstance(argument_aux, nodes.Call)
@@ -915,6 +934,16 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
                     break
             else:
                 self.add_message("external-request-timeout", node=node, args=(lib_original_func_name,))
+        if self.linter.is_message_enabled("bad-builtin-groupby", node.lineno) and node.func.as_string().endswith(
+            "groupby"
+        ):
+            if node.func.as_string() == "itertools.groupby":
+                self.add_message("bad-builtin-groupby", node=node)
+            elif not node.func.as_string().endswith("tools.groupby"):
+                # infer node is heavy so discarding cases early to improve perf
+                infer_node = utils.safe_infer(node.func)
+                if infer_node and infer_node.qname() == "itertools.groupby":
+                    self.add_message("bad-builtin-groupby", node=node)
 
     @utils.only_required_for_messages(
         "development-status-allowed",
@@ -1099,7 +1128,9 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
         self.check_odoo_relative_import(node)
         self.check_folder_test_imported(node)
 
-    @utils.only_required_for_messages("attribute-deprecated", "consider-merging-classes-inherited")
+    @utils.only_required_for_messages(
+        "attribute-deprecated", "consider-merging-classes-inherited", "no-wizard-in-models"
+    )
     def visit_assign(self, node):
         node_left = node.targets[0]
         if (
@@ -1110,7 +1141,9 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
         ):
             if node_left.name in self.linter.config.attribute_deprecated:
                 self.add_message("attribute-deprecated", node=node_left, args=(node_left.name,))
-        if self.linter.is_message_enabled("consider-merging-classes-inherited", node.lineno):
+        if self.linter.is_message_enabled(
+            "consider-merging-classes-inherited", node.lineno
+        ) or self.linter.is_message_enabled("no-wizard-in-models"):
             node_left = node.targets[0]
             if (
                 not isinstance(node_left, nodes.node_classes.AssignName)
@@ -1124,8 +1157,15 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
                 return
             odoo_class_name = getattr(node.parent, "odoo_attribute_name", None)
             odoo_class_inherit = node.value.value
-            if odoo_class_name and odoo_class_name != odoo_class_inherit:
+            # Used in no-wizard-in-models check
+            node.parent.odoo_attribute_inherit = odoo_class_inherit
+            if (
+                not self.linter.is_message_enabled("consider-merging-classes-inherited", node.lineno)
+                or odoo_class_name
+                and odoo_class_name != odoo_class_inherit
+            ):
                 # Skip _name='model.name' _inherit='other.model' because is valid
+                # Skip pylint magic disable comment for consider-merging-classes-inherited
                 return
             node_dirpath = os.path.dirname(node.root().file)
             manifest_path = misc.walk_up(node_dirpath, tuple(misc.MANIFEST_FILES), misc.top_path(node_dirpath))
@@ -1381,7 +1421,7 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
             return new_node, new_libname
         return self._get_root_method_assignation(new_node, new_libname)
 
-    def is_odoo_models_class(self, node):
+    def get_odoo_models_class(self, node):
         for class_base in node.bases:
             attr = class_base
             while True:
@@ -1397,16 +1437,27 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
                 package_names = imported_class.modname.split(".")[:1]
             elif isinstance(imported_class, nodes.Import):
                 package_names = [name[0].split(".")[0] for name in imported_class.names]
-            if "odoo" in package_names and class_base.as_string().split(".")[-1] in ["Model", "AbstractModel"]:
-                return True
+            if "odoo" in package_names:
+                class_base_name = class_base.as_string().split(".")[-1]
+                if class_base_name in ["Model", "AbstractModel", "TransientModel"]:
+                    return (class_base_name, class_base)
 
+    @utils.only_required_for_messages("no-write-in-compute", "no-wizard-in-models")
     def visit_classdef(self, node):
-        self.is_class_odoo_models = self.is_odoo_models_class(node)
+        self.class_odoo_models = self.get_odoo_models_class(node)
         self.odoo_computes = set()
 
+    @utils.only_required_for_messages("no-write-in-compute", "no-wizard-in-models")
     def leave_classdef(self, node):
-        if self.is_class_odoo_models:
+        if self.class_odoo_models:
             for odoo_compute in self.odoo_computes:
                 self.check_no_write_compute(node, odoo_compute)
+            if (
+                self.linter.is_message_enabled("no-wizard-in-models", self.class_odoo_models[1].lineno)
+                and self.class_odoo_models[0] == "TransientModel"
+                and os.path.basename(os.path.dirname(node.root().file)).startswith("model")
+                and not getattr(node, "odoo_attribute_inherit", "").startswith("res.config")
+            ):
+                self.add_message("no-wizard-in-models", node=self.class_odoo_models[1])
         self.odoo_computes = set()
-        self.is_class_odoo_models = False
+        self.class_odoo_models = False
